@@ -40,7 +40,7 @@ CREATE TABLE IF NOT EXISTS `tag` (
     `deleted` integer
 ); 
 
-CREATE TABLE IF NOT EXISTS pref_var (
+CREATE TABLE IF NOT EXISTS `pref_var` (
     `name` text primary key,
     `value` text
 );
